pub struct Unregistered {
pub operator: AccountId32,
pub blueprint_id: u64,
}Expand description
An operator has been unregistered.
Fields
operator: AccountId32blueprint_id: u64Trait Implementations
Sourceimpl Clone for Unregistered
impl Clone for Unregistered
Sourcefn clone(&self) -> Unregistered
fn clone(&self) -> Unregistered
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Unregistered
impl Debug for Unregistered
Sourceimpl Decode for Unregistered
impl Decode for Unregistered
Sourcefn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Unregistered, Error>where
__CodecInputEdqy: Input,
fn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Unregistered, Error>where
__CodecInputEdqy: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl DecodeAsFields for Unregistered
impl DecodeAsFields for Unregistered
Sourcefn decode_as_fields<R, 'info>(
input: &mut &[u8],
fields: &mut dyn FieldIter<'info, <R as TypeResolver>::TypeId, Item = Field<'info, <R as TypeResolver>::TypeId>>,
types: &'info R,
) -> Result<Unregistered, Error>where
R: TypeResolver,
fn decode_as_fields<R, 'info>(
input: &mut &[u8],
fields: &mut dyn FieldIter<'info, <R as TypeResolver>::TypeId, Item = Field<'info, <R as TypeResolver>::TypeId>>,
types: &'info R,
) -> Result<Unregistered, Error>where
R: TypeResolver,
Given some bytes and some fields denoting their structure, attempt to decode.
Sourceimpl Encode for Unregistered
impl Encode for Unregistered
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl EncodeAsFields for Unregistered
impl EncodeAsFields for Unregistered
Sourcefn encode_as_fields_to<ScaleEncodeResolver>(
&self,
__encode_as_type_fields: &mut dyn FieldIter<'_, <ScaleEncodeResolver as TypeResolver>::TypeId, Item = Field<'_, <ScaleEncodeResolver as TypeResolver>::TypeId>>,
__encode_as_type_types: &ScaleEncodeResolver,
__encode_as_type_out: &mut Vec<u8>,
) -> Result<(), Error>where
ScaleEncodeResolver: TypeResolver,
fn encode_as_fields_to<ScaleEncodeResolver>(
&self,
__encode_as_type_fields: &mut dyn FieldIter<'_, <ScaleEncodeResolver as TypeResolver>::TypeId, Item = Field<'_, <ScaleEncodeResolver as TypeResolver>::TypeId>>,
__encode_as_type_types: &ScaleEncodeResolver,
__encode_as_type_out: &mut Vec<u8>,
) -> Result<(), Error>where
ScaleEncodeResolver: TypeResolver,
Given some fields describing the shape of a type, attempt to encode to that shape.
Sourcefn encode_as_fields<R>(
&self,
fields: &mut dyn FieldIter<'_, <R as TypeResolver>::TypeId, Item = Field<'_, <R as TypeResolver>::TypeId>>,
types: &R,
) -> Result<Vec<u8>, Error>where
R: TypeResolver,
fn encode_as_fields<R>(
&self,
fields: &mut dyn FieldIter<'_, <R as TypeResolver>::TypeId, Item = Field<'_, <R as TypeResolver>::TypeId>>,
types: &R,
) -> Result<Vec<u8>, Error>where
R: TypeResolver,
This is a helper function which internally calls
EncodeAsFields::encode_as_fields_to. Prefer to
implement that instead.Sourceimpl EncodeAsType for Unregistered
impl EncodeAsType for Unregistered
Sourcefn encode_as_type_to<ScaleEncodeResolver>(
&self,
__encode_as_type_type_id: <ScaleEncodeResolver as TypeResolver>::TypeId,
__encode_as_type_types: &ScaleEncodeResolver,
__encode_as_type_out: &mut Vec<u8>,
) -> Result<(), Error>where
ScaleEncodeResolver: TypeResolver,
fn encode_as_type_to<ScaleEncodeResolver>(
&self,
__encode_as_type_type_id: <ScaleEncodeResolver as TypeResolver>::TypeId,
__encode_as_type_types: &ScaleEncodeResolver,
__encode_as_type_out: &mut Vec<u8>,
) -> Result<(), Error>where
ScaleEncodeResolver: TypeResolver,
Given some
type_id, types, a context and some output target for the SCALE encoded bytes,
attempt to SCALE encode the current value into the type given by type_id.Sourcefn encode_as_type<R>(
&self,
type_id: <R as TypeResolver>::TypeId,
types: &R,
) -> Result<Vec<u8>, Error>where
R: TypeResolver,
fn encode_as_type<R>(
&self,
type_id: <R as TypeResolver>::TypeId,
types: &R,
) -> Result<Vec<u8>, Error>where
R: TypeResolver,
This is a helper function which internally calls
EncodeAsType::encode_as_type_to. Prefer to
implement that instead.Sourceimpl IntoVisitor for Unregistered
impl IntoVisitor for Unregistered
Sourcetype AnyVisitor<ScaleDecodeTypeResolver: TypeResolver> = Visitor<ScaleDecodeTypeResolver>
type AnyVisitor<ScaleDecodeTypeResolver: TypeResolver> = Visitor<ScaleDecodeTypeResolver>
The visitor type used to decode SCALE encoded bytes to
Self.Sourcefn into_visitor<ScaleDecodeTypeResolver>() -> <Unregistered as IntoVisitor>::AnyVisitor<ScaleDecodeTypeResolver>where
ScaleDecodeTypeResolver: TypeResolver,
fn into_visitor<ScaleDecodeTypeResolver>() -> <Unregistered as IntoVisitor>::AnyVisitor<ScaleDecodeTypeResolver>where
ScaleDecodeTypeResolver: TypeResolver,
A means of obtaining this visitor.
Sourceimpl PartialEq for Unregistered
impl PartialEq for Unregistered
Sourceimpl StaticEvent for Unregistered
impl StaticEvent for Unregistered
impl EncodeLike for Unregistered
impl Eq for Unregistered
impl StructuralPartialEq for Unregistered