StorageApi

Struct StorageApi 

pub struct StorageApi;

Implementations

Source

impl StorageApi

pub fn account_iter( &self, ) -> DefaultAddress<(), AccountInfo<u32, AccountData<u128>>, (), Yes, Yes>

The full account information for a particular account ID.

pub fn account( &self, _0: impl Borrow<AccountId32>, ) -> DefaultAddress<StaticStorageKey<AccountId32>, AccountInfo<u32, AccountData<u128>>, Yes, Yes, ()>

The full account information for a particular account ID.

pub fn extrinsic_count(&self) -> DefaultAddress<(), u32, Yes, (), ()>

Total extrinsics count for the current block.

pub fn block_weight( &self, ) -> DefaultAddress<(), PerDispatchClass<Weight>, Yes, Yes, ()>

The current weight for the block.

pub fn all_extrinsics_len(&self) -> DefaultAddress<(), u32, Yes, (), ()>

Total length (in bytes) for all extrinsics put together, for the current block.

pub fn block_hash_iter(&self) -> DefaultAddress<(), H256, (), Yes, Yes>

Map of block numbers to block hashes.

pub fn block_hash( &self, _0: impl Borrow<u64>, ) -> DefaultAddress<StaticStorageKey<u64>, H256, Yes, Yes, ()>

Map of block numbers to block hashes.

pub fn extrinsic_data_iter(&self) -> DefaultAddress<(), Vec<u8>, (), Yes, Yes>

Extrinsics data for the current block (maps an extrinsic’s index to its data).

pub fn extrinsic_data( &self, _0: impl Borrow<u32>, ) -> DefaultAddress<StaticStorageKey<u32>, Vec<u8>, Yes, Yes, ()>

Extrinsics data for the current block (maps an extrinsic’s index to its data).

pub fn number(&self) -> DefaultAddress<(), u64, Yes, Yes, ()>

The current block number being processed. Set by execute_block.

pub fn parent_hash(&self) -> DefaultAddress<(), H256, Yes, Yes, ()>

Hash of the previous block.

pub fn digest(&self) -> DefaultAddress<(), Digest, Yes, Yes, ()>

Digest of the current block, also part of the block header.

pub fn events( &self, ) -> DefaultAddress<(), Vec<EventRecord<RuntimeEvent, H256>>, Yes, Yes, ()>

Events deposited for the current block.

NOTE: The item is unbound and should therefore never be read on chain. It could otherwise inflate the PoV size of a block.

Events have a large in-memory size. Box the events to not go out-of-memory just in case someone still reads them from within the runtime.

pub fn event_count(&self) -> DefaultAddress<(), u32, Yes, Yes, ()>

The number of events in the Events<T> list.

pub fn event_topics_iter( &self, ) -> DefaultAddress<(), Vec<(u64, u32)>, (), Yes, Yes>

Mapping between a topic (represented by T::Hash) and a vector of indexes of events in the <Events<T>> list.

All topic vectors have deterministic storage locations depending on the topic. This allows light-clients to leverage the changes trie storage tracking mechanism and in case of changes fetch the list of events of interest.

The value has the type (BlockNumberFor<T>, EventIndex) because if we used only just the EventIndex then in case if the topic has the same contents on the next block no notification will be triggered thus the event might be lost.

pub fn event_topics( &self, _0: impl Borrow<H256>, ) -> DefaultAddress<StaticStorageKey<H256>, Vec<(u64, u32)>, Yes, Yes, ()>

Mapping between a topic (represented by T::Hash) and a vector of indexes of events in the <Events<T>> list.

All topic vectors have deterministic storage locations depending on the topic. This allows light-clients to leverage the changes trie storage tracking mechanism and in case of changes fetch the list of events of interest.

The value has the type (BlockNumberFor<T>, EventIndex) because if we used only just the EventIndex then in case if the topic has the same contents on the next block no notification will be triggered thus the event might be lost.

pub fn last_runtime_upgrade( &self, ) -> DefaultAddress<(), LastRuntimeUpgradeInfo, Yes, (), ()>

Stores the spec_version and spec_name of when the last runtime upgrade happened.

pub fn upgraded_to_u32_ref_count( &self, ) -> DefaultAddress<(), bool, Yes, Yes, ()>

True if we have upgraded so that type RefCount is u32. False (default) if not.

pub fn upgraded_to_triple_ref_count( &self, ) -> DefaultAddress<(), bool, Yes, Yes, ()>

True if we have upgraded so that AccountInfo contains three types of RefCount. False (default) if not.

pub fn execution_phase(&self) -> DefaultAddress<(), Phase, Yes, (), ()>

The execution phase of the block.

pub fn authorized_upgrade( &self, ) -> DefaultAddress<(), CodeUpgradeAuthorization, Yes, (), ()>

Some if a code upgrade has been authorized.